@@ -31,13 +31,13 @@ calc.condlogLik <- function(y, X = NULL, family, trial.size = 1, lv.coefs, X.coe
             row.ids <- matrix(1:nrow(y), ncol = 1)
             colnames(row.ids) <- "ID1"
             }
-        row.ids <- check.row.ids(row.ids = row.ids, y = y)	
+        row.ids <- check_row_ids(row.ids = row.ids, y = y)	
             if(!is.list(row.coefs))
                 stop("row.coefs should be a list with length equal to the number of columns in row.coefs")
             if(length(row.coefs) != ncol(row.ids))
                 stop("row.coefs should be a list with length equal to the number of columns in row.coefs")
         }
-    check.offset(offset = offset, y = y)	
+    check_offset(offset = offset, y = y)	
             
 
     ## Finish checks
@@ -86,7 +86,7 @@ calc.condlogLik <- function(y, X = NULL, family, trial.size = 1, lv.coefs, X.coe
             if(complete_family[j] == "tweedie") 
                 loglik_comp[,j] <- dTweedie(as.vector(unlist(y[,j])), mu = exp(species_etas), phi = lv.coefs[j,ncol(lv.coefs)]+1e-6, p = powerparam, LOG = TRUE) 
         if(complete_family[j] == "ordinal") { 
-            get_probs <- ordinal.conversion.spp(n = n, lv = lv, lv.coefs.j = lv.coefs[j,], num.lv = num.lv, row.coefs = row.coefs, row.ids = row.ids, X = X, X.coefs.j = X.coefs[j,], cutoffs = cutoffs, est = "ignore"); 
+            get_probs <- ordinal_conversion(n = n, lv = lv, lv.coefs.j = lv.coefs[j,], num.lv = num.lv, row.coefs = row.coefs, row.ids = row.ids, X = X, X.coefs.j = X.coefs[j,], cutoffs = cutoffs, est = "ignore"); 
             for(i in 1:n) 
                 loglik_comp[i,j] <- log(get_probs[i,as.vector(y[i,j])]+1e-5) 
             }	
@@ -123,15 +123,15 @@ calc.logLik.lv0 <- function (y, X = NULL, family, trial.size = 1, lv.coefs,
             row.ids <- matrix(1:nrow(y), ncol = 1)
             colnames(row.ids) <- "ID1"
             }
-        row.ids <- check.row.ids(row.ids = row.ids, y = y)	
-        check.row.params(row.params = row.params, y = y, row.ids = row.ids)
+        row.ids <- check_row_ids(row.ids = row.ids, y = y)	
+        check_row_params(row.params = row.params, y = y, row.ids = row.ids)
         }
     if(row.eff == "fixed") 
         row.coefs <- row.params
     if(row.eff == "none") 
         row.coefs <- NULL
 
-    check.offset(offset = offset, y = y)
+    check_offset(offset = offset, y = y)
 
     if(any(complete_family == "ordinal") & is.null(cutoffs)) 
         stop("Ordinal data requires cutoffs to be supplied")
@@ -180,7 +180,7 @@ calc.logLik.lv0 <- function (y, X = NULL, family, trial.size = 1, lv.coefs,
             if(complete_family[j] == "tweedie") 
                 loglik_comp[, j] <- (dTweedie(as.vector(unlist(y[,j])), mu = exp(eta), phi = lv.coefs[j, 2], p = powerparam, LOG = TRUE))
             if(complete_family[j] == "ordinal") {
-                get_probs <- ordinal.conversion.spp(n = n, lv = NULL, lv.coefs.j = lv.coefs[j, ], num.lv = 0, row.coefs = row.coefs, row.ids = row.ids, X = X, X.coefs.j = X.coefs[j, ], offset.j = offset[,j], cutoffs = cutoffs, est = "ignore")
+                get_probs <- ordinal_conversion(n = n, lv = NULL, lv.coefs.j = lv.coefs[j, ], num.lv = 0, row.coefs = row.coefs, row.ids = row.ids, X = X, X.coefs.j = X.coefs[j, ], offset.j = offset[,j], cutoffs = cutoffs, est = "ignore")
                 for(i in 1:n) 
                     loglik_comp[i, j] <- log(get_probs[i, as.vector(y[i,j])] + 1e-05)
                 }
@@ -198,14 +198,14 @@ calc.logLik.lv0 <- function (y, X = NULL, family, trial.size = 1, lv.coefs,
             
     if(row.eff == "random") {
         loglik <- 0; loglik_comp <- numeric(n); 
-        mc.row.eff <- 1000
-        mc.row.coefs <- vector("list", ncol(row.ids))
+        mc_row_eff <- 1000
+        mc_row_coefs <- vector("list", ncol(row.ids))
         for(k in 1:ncol(row.ids)) 
-        mc.row.coefs[[k]] <- matrix(rnorm(length(unique(row.ids[,k]))*mc.row.eff, mean = 0, sd = row.params[[k]]), nrow = mc.row.eff) 
+        mc_row_coefs[[k]] <- matrix(rnorm(length(unique(row.ids[,k]))*mc_row_eff, mean = 0, sd = row.params[[k]]), nrow = mc_row_eff) 
     
         ordinal.conversion.special <- function(lv.coefs.j, row.coefs.i, X.i = NULL, X.coefs.j = NULL, offset.j = NULL, cutoffs) {
-            mc.row.eff <- length(row.coefs.i)
-            etas <- matrix(NA, mc.row.eff, length(cutoffs))
+            mc_row_eff <- length(row.coefs.i)
+            etas <- matrix(NA, mc_row_eff, length(cutoffs))
             for(k in 1:length(cutoffs)) {
                 etas[, k] <- cutoffs[k] - row.coefs.i - lv.coefs.j[1]
                 if(!is.null(X.coefs.j)) 
@@ -214,7 +214,7 @@ calc.logLik.lv0 <- function (y, X = NULL, family, trial.size = 1, lv.coefs,
                     etas[, k] <- etas[, k] - matrix(offset.j, ncol=1)
                 }
 
-            probs <- matrix(NA, mc.row.eff, length(cutoffs) + 1)
+            probs <- matrix(NA, mc_row_eff, length(cutoffs) + 1)
             probs[, 1] <- pnorm(etas[,1])
             for(k in 2:ncol(etas)) 
                 probs[, k] <- pnorm(etas[, k]) - pnorm(etas[,k-1])
@@ -224,44 +224,44 @@ calc.logLik.lv0 <- function (y, X = NULL, family, trial.size = 1, lv.coefs,
             }
 
         for(i in 1:n) {
-            spp_f <- eta <- matrix(lv.coefs[, 1], nrow = mc.row.eff, ncol = p, byrow = TRUE)
+            spp_f <- eta <- matrix(lv.coefs[, 1], nrow = mc_row_eff, ncol = p, byrow = TRUE)
         for(k in 1:ncol(row.ids)) 
-            eta <- eta + mc.row.coefs[[k]][,row.ids[i,k]]
+            eta <- eta + mc_row_coefs[[k]][,row.ids[i,k]]
 
             if(!is.null(X.coefs)) 
-                eta <- eta + matrix(t(as.matrix(X[i, ])) %*% t(X.coefs), nrow = mc.row.eff, ncol = p, byrow = TRUE)
+                eta <- eta + matrix(t(as.matrix(X[i, ])) %*% t(X.coefs), nrow = mc_row_eff, ncol = p, byrow = TRUE)
             if(!is.null(offset)) 
-                eta <- eta + matrix(offset[i,], nrow = mc.row.eff, ncol = p, byrow = TRUE)
+                eta <- eta + matrix(offset[i,], nrow = mc_row_eff, ncol = p, byrow = TRUE)
 
                 for(j in 1:p) {
                     if(complete_family[j] == "binomial") 
-                        spp_f[, j] <- dbinom(rep(as.vector(y[i, j]), mc.row.eff), complete_trial_size[j], prob = pnorm(eta[, j]))
+                        spp_f[, j] <- dbinom(rep(as.vector(y[i, j]), mc_row_eff), complete_trial_size[j], prob = pnorm(eta[, j]))
                     if(complete_family[j] == "poisson") 
-                        spp_f[, j] <- dpois(rep(as.vector(y[i, j]), mc.row.eff), exp(eta[, j]))
+                        spp_f[, j] <- dpois(rep(as.vector(y[i, j]), mc_row_eff), exp(eta[, j]))
                     if(complete_family[j] == "negative.binomial") 
-                        spp_f[, j] <- dnbinom(rep(as.vector(y[i, j]), mc.row.eff), size =1/(lv.coefs[j, ncol(lv.coefs)]+1e-5), mu = exp(eta[, j]))
+                        spp_f[, j] <- dnbinom(rep(as.vector(y[i, j]), mc_row_eff), size =1/(lv.coefs[j, ncol(lv.coefs)]+1e-5), mu = exp(eta[, j]))
                     if(complete_family[j] == "exponential") 
-                        spp_f[, j] <- dexp(rep(as.vector(y[i, j]), mc.row.eff), rate = 1/exp(eta[, j]))
+                        spp_f[, j] <- dexp(rep(as.vector(y[i, j]), mc_row_eff), rate = 1/exp(eta[, j]))
                     if(complete_family[j] == "gamma") 
-                        spp_f[, j] <- dgamma(rep(as.vector(y[i, j]), mc.row.eff), shape = exp(eta[, j]) * lv.coefs[j, ncol(lv.coefs)], rate = lv.coefs[j, ncol(lv.coefs)])
+                        spp_f[, j] <- dgamma(rep(as.vector(y[i, j]), mc_row_eff), shape = exp(eta[, j]) * lv.coefs[j, ncol(lv.coefs)], rate = lv.coefs[j, ncol(lv.coefs)])
                     if(complete_family[j] == "beta") 
-                        spp_f[, j] <- dbeta(rep(as.vector(y[i, j]), mc.row.eff), lv.coefs[j, ncol(lv.coefs)] * exp(eta[, j])/(1 + exp(eta[, j])), lv.coefs[j, ncol(lv.coefs)] * (1 - exp(eta[, j])/(1 + exp(eta[, j]))))
+                        spp_f[, j] <- dbeta(rep(as.vector(y[i, j]), mc_row_eff), lv.coefs[j, ncol(lv.coefs)] * exp(eta[, j])/(1 + exp(eta[, j])), lv.coefs[j, ncol(lv.coefs)] * (1 - exp(eta[, j])/(1 + exp(eta[, j]))))
                     if(complete_family[j] == "normal") 
-                        spp_f[, j] <- dnorm(rep(as.vector(y[i, j]), mc.row.eff), mean = eta[, j], sd = (lv.coefs[j, ncol(lv.coefs)]))
+                        spp_f[, j] <- dnorm(rep(as.vector(y[i, j]), mc_row_eff), mean = eta[, j], sd = (lv.coefs[j, ncol(lv.coefs)]))
                     if(complete_family[j] == "lnormal") 
-                        spp_f[, j] <- dlnorm(rep(as.vector(y[i, j]), mc.row.eff), meanlog = eta[, j], sdlog = (lv.coefs[j,ncol(lv.coefs)]))
+                        spp_f[, j] <- dlnorm(rep(as.vector(y[i, j]), mc_row_eff), meanlog = eta[, j], sdlog = (lv.coefs[j,ncol(lv.coefs)]))
                     if(complete_family[j] == "tweedie") { 
-                        spp_f[, j] <- dTweedie(rep(as.vector(y[i, j]), mc.row.eff), mu = exp(eta[, j]), phi = lv.coefs[j, ncol(lv.coefs)] + 1e-06, p = powerparam, LOG = FALSE)
+                        spp_f[, j] <- dTweedie(rep(as.vector(y[i, j]), mc_row_eff), mu = exp(eta[, j]), phi = lv.coefs[j, ncol(lv.coefs)] + 1e-06, p = powerparam, LOG = FALSE)
                         spp_f[, j][which(spp_f[, j] == 0)] <- 1 
                         }
                     if(complete_family[j] == "ordinal") {
-                        get_probs <- ordinal.conversion.special(lv.coefs.j = lv.coefs[j, ], row.coefs.i = rnorm(mc.row.eff, 0, sd = row.params[[1]]), X.i = X[i, ], X.coefs.j = X.coefs[j, ], cutoffs = cutoffs)
+                        get_probs <- ordinal.conversion.special(lv.coefs.j = lv.coefs[j, ], row.coefs.i = rnorm(mc_row_eff, 0, sd = row.params[[1]]), X.i = X[i, ], X.coefs.j = X.coefs[j, ], cutoffs = cutoffs)
                         spp_f[, j] <- get_probs[, as.vector(y[i, j])] + 1e-05 
                         }
                     }
                         
                 spp_f[!is.finite(spp_f)] = 1
-                spp_f <- matrix(spp_f, nrow = mc.row.eff, byrow = FALSE)
+                spp_f <- matrix(spp_f, nrow = mc_row_eff, byrow = FALSE)
                 Q <- mean(apply(spp_f, 1, prod))
                 loglik <- loglik + log(Q)
                 loglik_comp[i] <- log(Q)
@@ -284,7 +284,7 @@ calc.marglogLik <- function (y, X = NULL, family, trial.size = 1, lv.coefs,
      X.coefs = NULL, row.eff = "none", row.params = NULL, row.ids = NULL, offset = NULL, num.lv, 
      lv.mc = NULL, cutoffs = NULL, powerparam = NULL) { 
 	
-    warning("Please note that as of version 1.6, this function to calculate marginal log-likelihoods will no longer be updated. Use at your peril!")
+    warning("Please note that as of version 1.6, this function to calculate marginal log-likelihoods will no longer be updated. Use at your own peril!")
 
     if(num.lv == 0) 
         stop("Please use calc.loglik.lv0 to calculate likelihood in boral models with no latent variables")
@@ -315,13 +315,13 @@ calc.marglogLik <- function (y, X = NULL, family, trial.size = 1, lv.coefs,
             row.ids <- matrix(1:nrow(y), ncol = 1)
             colnames(row.ids) <- "ID1"
             }
-        row.ids <- check.row.ids(row.ids = row.ids, y = y)	
-        check.row.params(row.params = row.params, y = y, row.ids = row.ids)
+        row.ids <- check_row_ids(row.ids = row.ids, y = y)	
+        check_row_params(row.params = row.params, y = y, row.ids = row.ids)
         }
     if(row.eff == "fixed") 
         row.coefs <- row.params
 
-    check.offset(offset = offset, y = y)
+    check_offset(offset = offset, y = y)
     
     if(any(complete_family == "ordinal") & is.null(cutoffs)) 
         stop("Ordinal data requires cutoffs to be supplied")
@@ -357,9 +357,9 @@ calc.marglogLik <- function (y, X = NULL, family, trial.size = 1, lv.coefs,
             
     index_multinom_cols <- which(complete_family == "multinom")
     if(row.eff == "random") {
-        mc.row.coefs <- vector("list", ncol(row.ids))
+        mc_row_coefs <- vector("list", ncol(row.ids))
         for(k in 1:ncol(row.ids)) 
-            mc.row.coefs[[k]] <- matrix(rnorm(length(unique(row.ids[,k]))*numrows_mclv, mean = 0, sd = row.params[[k]]), nrow = numrows_mclv) 
+            mc_row_coefs[[k]] <- matrix(rnorm(length(unique(row.ids[,k]))*numrows_mclv, mean = 0, sd = row.params[[k]]), nrow = numrows_mclv) 
         }
 
         
@@ -374,7 +374,7 @@ calc.marglogLik <- function (y, X = NULL, family, trial.size = 1, lv.coefs,
             }
         if(row.eff == "random") {
             for(k in 1:ncol(row.ids)) 
-                spp.att.eta <- spp.att.eta + mc.row.coefs[[k]][,row.ids[i,k]]
+                spp.att.eta <- spp.att.eta + mc_row_coefs[[k]][,row.ids[i,k]]
             }
         if(!is.null(X.coefs)) 
             spp.att.eta <- spp.att.eta + matrix(t(as.matrix(X[i, ])) %*% t(X.coefs), nrow = numrows_mclv, ncol = p, byrow = TRUE)
